{
  'target_defaults': {
    'variables': {
      'deps': [
        'libchrome-<(libbase_ver)',
        'libchromeos-<(libbase_ver)',
        'system_api',
      ],
    },
    'include_dirs': [
      '.',
    ],
  },
  'targets': [
    {
      'target_name': 'buffet_common',
      'type': 'static_library',
      'variables': {
        'dbus_adaptors_out_dir': 'include/buffet/dbus_bindings',
        'dbus_service_config': 'dbus_bindings/dbus-service-config.json',
        'exported_deps': [
          'libweave-<(libbase_ver)',
        ],
        'deps': ['>@(exported_deps)'],
      },
      'all_dependent_settings': {
        'variables': {
          'deps': [
            '<@(exported_deps)',
          ],
        },
      },
      'sources': [
        'ap_manager_client.cc',
        'buffet_config.cc',
        'dbus_bindings/com.android.Weave.Command.dbus-xml',
        'dbus_bindings/com.android.Weave.Manager.dbus-xml',
        'dbus_command_dispatcher.cc',
        'dbus_command_proxy.cc',
        'dbus_conversion.cc',
        'dbus_constants.cc',
        'http_transport_client.cc',
        'manager.cc',
        'shill_client.cc',
        'socket_stream.cc',
      ],
      'conditions': [
        ['USE_wifi_bootstrapping == 1', {
          'variables': {
            'exported_deps': [
              'libpeerd-client',
              'libwebserv-<(libbase_ver)',
            ],
          },
          'all_dependent_settings': {
            'defines': [ 'BUFFET_USE_WIFI_BOOTSTRAPPING' ],
          },
          'defines': [ 'BUFFET_USE_WIFI_BOOTSTRAPPING' ],
          'sources': [
            'webserv_client.cc',
            'peerd_client.cc',
          ],
        }],
      ],
      'includes': ['../common-mk/generate-dbus-adaptors.gypi'],
      'actions': [
        {
          'action_name': 'generate-buffet-proxies',
          'variables': {
            'dbus_service_config': 'dbus_bindings/dbus-service-config.json',
            'proxy_output_file': 'include/buffet/dbus-proxies.h'
          },
          'sources': [
            'dbus_bindings/com.android.Weave.Command.dbus-xml',
            'dbus_bindings/com.android.Weave.Manager.dbus-xml',
          ],
          'includes': ['../common-mk/generate-dbus-proxies.gypi'],
        },
        {
          # Import D-Bus bindings from shill.
          'action_name': 'generate-shill-proxies',
          'variables': {
            'dbus_service_config': '../shill/dbus_bindings/dbus-service-config.json',
            'proxy_output_file': 'include/shill/dbus-proxies.h'
          },
          'sources': [
            '../shill/dbus_bindings/com.chromium.flimflam.Device.xml',
            '../shill/dbus_bindings/com.chromium.flimflam.Manager.xml',
            '../shill/dbus_bindings/com.chromium.flimflam.Service.xml',
          ],
          'includes': ['../common-mk/generate-dbus-proxies.gypi'],
        },
        {
          # Import D-Bus bindings from apmanager.
          'action_name': 'generate-apmanager-proxies',
          'variables': {
            'dbus_service_config': '../apmanager/dbus_bindings/dbus-service-config.json',
            'proxy_output_file': 'include/apmanager/dbus-proxies.h'
          },
          'sources': [
            '../apmanager/dbus_bindings/com.chromium.apmanager.Config.xml',
            '../apmanager/dbus_bindings/com.chromium.apmanager.Device.xml',
            '../apmanager/dbus_bindings/com.chromium.apmanager.Manager.xml',
            '../apmanager/dbus_bindings/com.chromium.apmanager.Service.xml',
          ],
          'includes': ['../common-mk/generate-dbus-proxies.gypi'],
        },
      ],
    },
    {
      'target_name': 'buffet',
      'type': 'executable',
      'dependencies': [
        'buffet_common',
      ],
      'sources': [
        'main.cc',
      ],
    },
    {
      'target_name': 'buffet_test_daemon',
      'type': 'executable',
      'sources': [
        'test_daemon/main.cc',
      ],
    },
    {
      'target_name': 'buffet_client',
      'type': 'executable',
      'sources': [
        'buffet_client.cc',
      ],
    },
  ],
  'conditions': [
    ['USE_test == 1', {
      'targets': [
        {
          'target_name': 'buffet_testrunner',
          'type': 'executable',
          'dependencies': [
            'buffet_common',
          ],
          'variables': {
            'deps': [
              'libchrome-test-<(libbase_ver)',
              'libchromeos-test-<(libbase_ver)',
              'libweave-test-<(libbase_ver)',
            ],
          },
          'includes': ['../common-mk/common_test.gypi'],
          'sources': [
            'buffet_config_unittest.cc',
            'buffet_testrunner.cc',
            'dbus_command_proxy_unittest.cc',
            'dbus_conversion_unittest.cc',
          ],
        },
      ],
    }],
  ],
}
